==> antspynet-0.2.1.tar.gz: antspynet-0.2.1/antspynet/architectures/__init__.py <==

from .create_autoencoder_model import create_autoencoder_model
from .create_convolutional_autoencoder_model import create_convolutional_autoencoder_model_2d, create_convolutional_autoencoder_model_3d

from .create_alexnet_model import create_alexnet_model_2d, create_alexnet_model_3d
from .create_densenet_model import create_densenet_model_2d, create_densenet_model_3d
from .create_resnet_model import create_resnet_model_2d, create_resnet_model_3d
from .create_simple_classification_with_spatial_transformer_network_model import create_simple_classification_with_spatial_transformer_network_model_2d, create_simple_classification_with_spatial_transformer_network_model_3d

from .create_deep_back_projection_network_model import create_deep_back_projection_network_model_2d, create_deep_back_projection_network_model_3d
from .create_deep_denoise_super_resolution_model import create_deep_denoise_super_resolution_model_2d, create_deep_denoise_super_resolution_model_3d
from .create_denoising_auto_encoder_super_resolution_model import create_denoising_auto_encoder_super_resolution_model_2d, create_denoising_auto_encoder_super_resolution_model_3d
from .create_expanded_super_resolution_model import create_expanded_super_resolution_model_2d, create_expanded_super_resolution_model_3d
from .create_image_super_resolution_model import create_image_super_resolution_model_2d, create_image_super_resolution_model_3d
from .create_resnet_super_resolution_model import create_resnet_super_resolution_model_2d, create_resnet_super_resolution_model_3d
from .create_vgg_model import create_vgg_model_2d, create_vgg_model_3d
from .create_wide_resnet_model import create_wide_resnet_model_2d, create_wide_resnet_model_3d

from .create_unet_model import create_unet_model_2d, create_unet_model_3d
from .create_resunet_model import create_resunet_model_2d, create_resunet_model_3d
from .create_denseunet_model import create_denseunet_model_2d, create_denseunet_model_3d
from .create_custom_unet_model import create_nobrainer_unet_model_3d
from .create_custom_unet_model import create_hippmapp3r_unet_model_3d
from .create_custom_unet_model import create_hypermapp3r_unet_model_3d
from .create_custom_unet_model import create_sysu_media_unet_model_2d
from .create_custom_unet_model import create_hypothalamus_unet_model_3d
from .create_partial_convolution_unet_model import create_partial_convolution_unet_model_2d, create_partial_convolution_unet_model_3d

from .create_custom_model import create_simple_fully_convolutional_network_model_3d

from .create_vanilla_gan_model import VanillaGanModel
from .create_deep_convolutional_gan_model import DeepConvolutionalGanModel
from .create_wasserstein_gan_model import WassersteinGanModel
from .create_improved_wasserstein_gan_model import ImprovedWassersteinGanModel
from .create_cycle_gan_model import CycleGanModel
from .create_super_resolution_gan_model import SuperResolutionGanModel

from .create_dense_model import create_dense_model

==> antspynet-0.3.1.tar.gz: antspynet-0.3.1/antspynet/architectures/__init__.py <==

from .create_autoencoder_model import create_autoencoder_model
from .create_convolutional_autoencoder_model import create_convolutional_autoencoder_model_2d, create_convolutional_autoencoder_model_3d

from .create_alexnet_model import create_alexnet_model_2d, create_alexnet_model_3d
from .create_densenet_model import create_densenet_model_2d, create_densenet_model_3d
from .create_resnet_model import create_resnet_model_2d, create_resnet_model_3d
from .create_simple_classification_with_spatial_transformer_network_model import create_simple_classification_with_spatial_transformer_network_model_2d, create_simple_classification_with_spatial_transformer_network_model_3d

from .create_deep_back_projection_network_model import create_deep_back_projection_network_model_2d, create_deep_back_projection_network_model_3d
# from .create_deep_denoise_super_resolution_model import create_deep_denoise_super_resolution_model_2d, create_deep_denoise_super_resolution_model_3d
from .create_denoising_auto_encoder_super_resolution_model import create_denoising_auto_encoder_super_resolution_model_2d, create_denoising_auto_encoder_super_resolution_model_3d
from .create_expanded_super_resolution_model import create_expanded_super_resolution_model_2d, create_expanded_super_resolution_model_3d
from .create_image_super_resolution_model import create_image_super_resolution_model_2d, create_image_super_resolution_model_3d
from .create_resnet_super_resolution_model import create_resnet_super_resolution_model_2d, create_resnet_super_resolution_model_3d
from .create_vgg_model import create_vgg_model_2d, create_vgg_model_3d
from .create_wide_resnet_model import create_wide_resnet_model_2d, create_wide_resnet_model_3d

from .create_unet_model import create_unet_model_2d, create_unet_model_3d
from .create_resunet_model import create_resunet_model_2d, create_resunet_model_3d
from .create_denseunet_model import create_denseunet_model_2d, create_denseunet_model_3d
from .create_custom_unet_model import create_nobrainer_unet_model_3d
from .create_custom_unet_model import create_hippmapp3r_unet_model_3d
from .create_custom_unet_model import create_hypermapp3r_unet_model_3d
from .create_custom_unet_model import create_sysu_media_unet_model_2d, create_sysu_media_unet_model_3d
from .create_custom_unet_model import create_hypothalamus_unet_model_3d
from .create_custom_unet_model import create_shiva_unet_model_3d
from .create_partial_convolution_unet_model import create_partial_convolution_unet_model_2d, create_partial_convolution_unet_model_3d
# from .create_diffusion_probabilistic_unet_model import create_diffusion_probabilistic_unet_model_2d, create_diffusion_probabilistic_unet_model_3d

from .create_custom_model import create_simple_fully_convolutional_network_model_3d
from .create_custom_model import create_rmnet_generator

from .create_vanilla_gan_model import VanillaGanModel
from .create_deep_convolutional_gan_model import DeepConvolutionalGanModel
from .create_wasserstein_gan_model import WassersteinGanModel
from .create_improved_wasserstein_gan_model import ImprovedWassersteinGanModel
from .create_cycle_gan_model import CycleGanModel
from .create_super_resolution_gan_model import SuperResolutionGanModel

from .create_dense_model import create_dense_model

from .create_transformer_model import create_vision_transformer_model_2d, create_vision_transformer_model_3d
from .create_transformer_model import create_compact_convolutional_transformer_model_2d, create_compact_convolutional_transformer_model_3d
